#include <avr/io.h>
#include <util/delay.h>

#include "Nokia5110/Nokia5110.h"

#define left_pad	0
#define right_pad	81

void adc_init()
{
    // AREF = AVcc
    ADMUX = (1<<REFS0);
    // ADC Enable and prescaler of 128
    ADCSRA = (1<<ADEN)|(1<<ADPS2)|(1<<ADPS1)|(1<<ADPS0);
}

uint16_t adc_read(uint8_t ch)
{
	// select the corresponding channel 0~7
	ch &= 0b00000111;  // AND operation with 7
	ADMUX = (ADMUX & 0xF8)|ch; // clears the bottom 3 bits before ORing
	// start single convertion
	ADCSRA |= (1<<ADSC);
	// wait for conversion to complete
	while(ADCSRA & (1<<ADSC));
	return (ADC);
}

void move_pad(int pad, int position)
{
	int i;
	// get new position for left or right pad
	int x = position * 30 / 1023;
	// turn on pixels for pad
	for(i=x; i<x+12; i++){
		lcd_setpixel(pad, i);
		lcd_setpixel(pad+1, i);
		lcd_setpixel(pad+2, i);
	}
}

// turn on pixels for ball
void move_ball(int x, int y)
{
	lcd_setpixel(x-1, y-1);
	lcd_setpixel(x-1, y);
	lcd_setpixel(x-1, y+1);
	lcd_setpixel(x, y-1);
	lcd_setpixel(x, y);
	lcd_setpixel(x, y+1);
	lcd_setpixel(x+1, y-1);
	lcd_setpixel(x+1, y);
	lcd_setpixel(x+1, y+1);
}

int main(void) 
{	
	int i;
	// OX and OY for ball
	int x=42, y=20;
	// how fast is ball (pixels/second)
	int speed = 0;
	// start LCD and ADC
	LCD_init();
	adc_init();
	
	// start game
	while(1){
		// draw floor on bottom of LCD
		for(i=0; i<84; i++){
			lcd_setpixel(i, 42);
		}
		// refresh ball position
		move_ball(x, y);
		// refresh left pad position
		move_pad(left_pad, adc_read(0));
		// refresh right pad position
		move_pad(right_pad, adc_read(1));
		// draw all pixels set
		lcd_update();
		_delay_ms(100);
		// clear old pixels
		lcd_clear();
	}
	

}